==> 0.16.0.tar.gz: lib/ngx_core.dart <==
/// Core library for [AngularDart](https://webdev.dartlang.org/angular) applications.
library ngx_core;

import 'dart:async';
import 'dart:collection';
import 'dart:convert';
import 'dart:html' as dom;
import 'dart:math' show Point;
import 'dart:typed_data';
import 'package:angular/angular.dart';
import 'package:angular/security.dart';
import 'package:angular_router/angular_router.dart';
import 'package:biscuits/biscuits.dart' hide SimpleChange;
import 'package:crypto/crypto.dart';

part 'src/directives/document_title.dart';
part 'src/directives/go_back.dart';
part 'src/directives/scroll_to.dart';

part 'src/models/identity.dart';
part 'src/models/pagination.dart';
part 'src/models/sort.dart';
part 'src/models/validation_error.dart';

part 'src/pipes/auto_link_pipe.dart';
part 'src/pipes/encode_uri_pipe.dart';
part 'src/pipes/nl2br_pipe.dart';
part 'src/pipes/safe_pipe.dart';
part 'src/pipes/title_case_pipe.dart';

part 'src/services/application.dart';
part 'src/services/configuration.dart';
part 'src/services/document_ref.dart';
part 'src/services/meta.dart';
part 'src/services/security.dart';
part 'src/services/session.dart';
part 'src/services/title.dart';
part 'src/services/viewport_scroller.dart';

/// A convenience list of all directives exposed by this library.
const List ngxDirectives = [DocumentTitle, GoBack];

/// A convenience list of all pipes exposed by this library.
const List ngxPipes = [EncodeUriPipe, Nl2brPipe, SafePipe];

/// A convenience list of all providers exposed by this library.
const Module ngxProviders = Module(provide: [
  ClassProvider(Application),
  ClassProvider(Configuration),
  ClassProvider(DocumentRef),
  ClassProvider(Meta),
  ClassProvider(Session),
  ClassProvider(Title)
]);

==> 0.17.0.tar.gz: lib/ngx_core.dart <==
/// Core library for [AngularDart](https://webdev.dartlang.org/angular) applications.
library ngx_core;

import 'dart:async';
import 'dart:collection';
import 'dart:convert';
import 'dart:html' as dom;
import 'dart:math' show Point;
import 'dart:typed_data';
import 'package:angular/angular.dart';
import 'package:angular/security.dart';
import 'package:angular_forms/angular_forms.dart';
import 'package:angular_router/angular_router.dart';
import 'package:crypto/crypto.dart';
import 'package:rxdart/rxdart.dart';

part 'src/helpers.dart';

part 'src/directives/document_title.dart';
part 'src/directives/go_back.dart';
part 'src/directives/scroll_to.dart';

part 'src/models/breakpoints.dart';
part 'src/models/pagination.dart';
part 'src/models/session.dart';
part 'src/models/sort.dart';
part 'src/models/validation_error.dart';

part 'src/pipes/auto_link_pipe.dart';
part 'src/pipes/encode_uri_pipe.dart';
part 'src/pipes/nl2br_pipe.dart';
part 'src/pipes/safe_pipe.dart';
part 'src/pipes/title_case_pipe.dart';

part 'src/services/application.dart';
part 'src/services/configuration.dart';
part 'src/services/document_ref.dart';
part 'src/services/downloader.dart';
part 'src/services/meta.dart';
part 'src/services/security.dart';
part 'src/services/session.dart';
part 'src/services/title.dart';
part 'src/services/viewport_scroller.dart';

/// A convenience list of all directives exposed by this library.
const List ngxDirectives = [DocumentTitle, GoBack, ScrollTo];

/// A convenience list of all pipes exposed by this library.
const List ngxPipes = [
  AutoLinkPipe,
  EncodeUriPipe,
  Nl2brPipe,
  SafePipe,
  TitleCasePipe
];

/// A convenience list of all providers exposed by this library.
const Module ngxProviders = Module(provide: [
  ClassProvider(Application),
  ClassProvider(Configuration),
  ClassProvider(DocumentRef),
  ClassProvider(Downloader),
  ClassProvider(Meta),
  ClassProvider(Security),
  ClassProvider(Session),
  ClassProvider(Title),
  ClassProvider(ViewportScroller)
]);
